﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using DlhSoft.Windows.Data;

namespace GanttChartTaskListViewCustomDataBindingSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();

            // Prepare the task data collection of CustomTaskItem type.
            // It is recommended to use a collection that implements INotifyCollectionChanged such as ObservableCollection if you plan to change it by adding or removing items dynamically.
            ObservableCollection<CustomTaskItem> taskItems = new ObservableCollection<CustomTaskItem>
            {
                new CustomTaskItem { DisplayName = "Task 1", TaskIndex = "1", Description = "Description of Task 1" },
                new CustomTaskItem { DisplayName = "Task 1.1", IndentLevel = 1, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00"), CompletedWorkEffort = TimeSpan.Parse("04:00:00"), TaskIndex = "2", Description = "Description of Task 1.1" },
                new CustomTaskItem { DisplayName = "Task 1.2", IndentLevel = 1, TaskIndex = "3", Description = "Description of Task 1.2" },
                new CustomTaskItem { DisplayName = "Task 1.2.1", IndentLevel = 2, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00"), TaskIndex = "4", Description = "Description of Task 1.2.1" },
                new CustomTaskItem { DisplayName = "Task 1.2.2", IndentLevel = 2, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("16:00:00"), TaskIndex = "5", Description = "Description of Task 1.2.2" },
                new CustomTaskItem { DisplayName = "Task 2", IsOpen = true, TaskIndex = "6", Description = "Description of Task 2" },
                new CustomTaskItem { DisplayName = "Task 2.1", IndentLevel = 1, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("16:00:00"), IsWorkCompleted = true, TaskIndex = "7", Description = "Description of Task 2.1" },
                new CustomTaskItem { DisplayName = "Task 2.2", IndentLevel = 1, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00"), CompletedWorkEffort = TimeSpan.Parse("06:00:00"), TaskIndex = "8", Description = "Description of Task 2.2" },
                new CustomTaskItem { DisplayName = "Task 2.3", IndentLevel = 1, IsOpen = true, TaskIndex = "9", PredecessorTaskIndexes = "8", Description = "Description of Task 2.3" },
                new CustomTaskItem { DisplayName = "Task 2.3.1", IndentLevel = 2, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("1.16:00:00"), TaskIndex = "10", TaskCost = 2000, Description = "Description of Task 2.3.1" },
                new CustomTaskItem { DisplayName = "Task 2.3.2", IndentLevel = 2, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00"), TaskIndex = "11", PredecessorTaskIndexes = "10", Description = "Description of Task 2.3.2" },
                new CustomTaskItem { DisplayName = "Task 3", StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("12:30:00"), CompletedWorkEffort = TimeSpan.Parse("02:30:00"), TaskIndex = "12", PredecessorTaskIndexes = "9, 11SS+12", Description = "Description of Task 3" },
                new CustomTaskItem { DisplayName = "Task 4", StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("16:00:00"), AssignedResources = "Resource 1", TaskIndex = "13", Description = "Description of Task 4" },
                new CustomTaskItem { DisplayName = "Task 5", StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("20:00:00"), AssignedResources = "Resource 1, Resource 2 [50%]", TaskIndex = "14", Description = "Description of Task 5" },
                new CustomTaskItem { DisplayName = "Task 6", StartDate = DateTime.Today, IsMilestoneTask = true, TaskIndex = "15", PredecessorTaskIndexes = "14+2", Description = "Description of Task 6" }
            };

            for (int i = 7; i <= 64; i++)
                taskItems.Add(new CustomTaskItem { DisplayName = "Task " + i, StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00"), Description = "Description of Task " + i });

            ObservableCollection<ResourceItem> assignableResourceItems = new ObservableCollection<ResourceItem>
            {
                new ResourceItem { Content = "Resource 1", CostPerUsage = 100, CostPerHour = 10 },
                new ResourceItem { Content = "Resource 2", CostPerHour = 20 }
            };

            for (int i = 3; i <= 16; i++)
                assignableResourceItems.Add(new ResourceItem { Content = "Resource " + i });

            // MemberPath properties are set to the appropriate member property paths for the CustomTaskItem type in markup.
            GanttChartTaskListView.AssignableResourceItemsSource = assignableResourceItems;
            GanttChartTaskListView.ItemsSource = taskItems;
        }

        // Event handler for creating new custom tasks when the end user executes the Insert New command of the control.
        private void GanttChartTaskListView_NewTask(object sender, NewItemEventArgs e)
        {
            e.Item = new CustomTaskItem { DisplayName = "New Task", StartDate = DateTime.Today, WorkEffort = TimeSpan.Parse("08:00:00") };
        }
    }
}
